/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.controller.api;

import fr.unistra.sil.erp.back.model.ErrorMessage;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

/**
 * Handles API exceptions.
 * 
 * When an Exception is thrown while processing a request, the behavior
 * to adopt for each Exception is defined here.
 * 
 * @author BEAUVAIS ANTOINE
 */
@RestControllerAdvice
public class ApiErrorHandler {
    
    /**
     * Handler for HTTP 500 Internal Server Error.
     * @param ex the thrown Exception.
     * @param request the HTTP Servlet request, provided by Spring.
     * @param response the HTTP Servlet response, provided by Spring.
     * @return the response to the client.
     */
    @ExceptionHandler(ApiServerErrorException.class)
    public ResponseEntity<Object> handleServerError(Exception ex,
            HttpServletRequest request, HttpServletResponse response)
    {
        return new ResponseEntity<>(new ErrorMessage(ex.getMessage()),
                HttpStatus.INTERNAL_SERVER_ERROR);
    }
    
    /**
     * Handler for HTTP 400 Bad Request.
     * @param ex the thrown Exception.
     * @param request the HTTP Servlet request.
     * @param response the HTTP Servlet response.
     * @return the response to the client.
     */
    @ExceptionHandler(ApiBadRequestException.class)
    public ResponseEntity<Object> handleBadRequest(Exception ex,
            HttpServletRequest request, HttpServletResponse response)
    {
        return new ResponseEntity<>(new ErrorMessage(ex.getMessage()),
                HttpStatus.BAD_REQUEST);
    }
    
}
