/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.db;

import fr.unistra.sil.erp.back.model.Category;
import fr.unistra.sil.erp.back.model.Item;
import fr.unistra.sil.erp.back.model.Stock;
import java.util.List;

/**
 * Standard interface for database implementations.
 * 
 * This interface allows the application to be able to use different
 * database systems (CSV, SQLite, MySQL...) by simply switching
 * implementations.
 * @author BEAUVAIS ANTOINE
 */
public interface DatabaseInterface {
    
    /**
     * Returns the list of all items.
     * @return the list of all items, or null if an error occurred.
     */
    public List<Item> getAllItems();
    
    /**
     * Returns the list of all items for a given category.
     * @param category the category's identifier.
     * @return the list of items, or null if an error occurred.
     */
    public List<Item> getItemsFromCategory(int category);
    
    /**
     * Returns the list of all categories.
     * 
     * @return the list of categories, or null if an error occurred.
     */
    public List<Category> getCategories();
    
    /**
     * Returns the list of all stocks.
     * 
     * @return the list of stocks.
     */
    public List<Stock> getStocks();
    
}
